@@ -1,4 +1,5 @@
 import os
+import re
 import json
 import time
 import datetime
@@ -25,7 +26,6 @@ dict_init_arg = {
     "model_id_lst": str,
     "profile_id_lst": str,
     "tag_lst": str,
-    "model_name_lst": str,
     "training_start_time_lst": str,
     "total_training_time_lst": int,
     "training_start_time_lst": datetime,
@@ -51,50 +51,87 @@ class TrainModelToSQl:
 
     def performance(self, dict_init_arg: dict):
         mp = ModelPerfornance(score_type='policy_score')
-        result = mp.performance_output(dict_init_arg["list_y_test"], dict_init_arg["list_y_score"])
-
-        result = {
-            'customer_id': dict_init_arg["customer_id_lst"],
-            'training_id': dict_init_arg["training_id_lst"],
-            'model_id': dict_init_arg["model_id_lst"],
-            'profile_id': dict_init_arg["profile_id_lst"],
-            'tag': dict_init_arg["tag_lst"],
-            # 'connector_id': dict_init_arg["connector_id_lst"],
-            # 'institute_id': dict_init_arg["institute_id_lst"],
-            # 'operator_id': dict_init_arg["operator_id_lst"],
-            'model_name': dict_init_arg["model_name_lst"],
-            'training_start_time': dict_init_arg["training_start_time_lst"],
-            'training_end_time': dict_init_arg["training_end_time_lst"],
-            'total_training_time': dict_init_arg["total_training_time_lst"],
-            'training_data_start_date': dict_init_arg["training_start_time_lst"],
-            'training_data_end_date': dict_init_arg["training_end_time_lst"],
-            'number_of_dump_data': dict_init_arg["number_of_dump_data"],
-            'number_of_training_data': dict_init_arg["number_of_training_data"],
-            'number_of_positive_samples_in_training_data': dict_init_arg["number_of_positive_samples_in_training_data"],
-            'number_of_negative_samples_in_training_data': dict_init_arg["number_of_negative_samples_in_training_data"],
-            'number_of_validation_data': dict_init_arg["number_of_validation_data"],
-            'true_label_column': dict_init_arg["true_label_column_lst"],
-            'number_of_positive_samples_in_validation_data': dict_init_arg["number_of_positive_samples_in_validation_data"],
-            'number_of_negative_samples_in_validation_data': dict_init_arg["number_of_negative_samples_in_validation_data"],
-            'threshold': [result['threshold_lst']],
-            'tp': [result['tp_lst']],
-            'fp': [result['fp_lst']],
-            'tn': [result['tn_lst']],
-            'fn': [result['fn_lst']],
-            'accuracy': [result['accuracy_lst']],
-            'ppv': [result['precision_lst']],
-            'recall': [result['recall_lst']],
-            'f1_score': [result['f1_score_lst']],
-            'fnr': [result['fnr_lst']],
-            'fpr': [result['fpr_lst']],
-            'npv': [result['npv_lst']],
-            'fdr': [result['fdr_lst']],
-            'for_': [result['for_lst']],
-            'tnr': [result['tnr_lst']],
-            'auc': result['auc_lst'],
-            "return_code": dict_init_arg['return_code'],
-            "reason": dict_init_arg['reason']
-        }
+        try:
+            result = mp.performance_output(dict_init_arg["list_y_test"], dict_init_arg["list_y_score"])
+            result = {
+                'customer_id': dict_init_arg["customer_id_lst"],
+                'training_id': dict_init_arg["training_id_lst"],
+                'model_id': dict_init_arg["model_id_lst"],
+                'profile_id': dict_init_arg["profile_id_lst"],
+                'tag': dict_init_arg["tag_lst"],
+                'model_name': dict_init_arg["model_id_lst"] + "-" + "".join(re.findall(r'\d+', str(datetime.datetime.now()))),
+                'training_start_time': dict_init_arg["training_start_time_lst"],
+                'training_end_time': dict_init_arg["training_end_time_lst"],
+                'total_training_time': dict_init_arg["total_training_time_lst"],
+                'training_data_start_date': dict_init_arg["training_start_time_lst"],
+                'training_data_end_date': dict_init_arg["training_end_time_lst"],
+                'number_of_dump_data': dict_init_arg["number_of_dump_data"],
+                'number_of_training_data': dict_init_arg["number_of_training_data"],
+                'number_of_positive_samples_in_training_data': dict_init_arg["number_of_positive_samples_in_training_data"],
+                'number_of_negative_samples_in_training_data': dict_init_arg["number_of_negative_samples_in_training_data"],
+                'number_of_validation_data': dict_init_arg["number_of_validation_data"],
+                'true_label_column': dict_init_arg["true_label_column_lst"],
+                'number_of_positive_samples_in_validation_data': dict_init_arg["number_of_positive_samples_in_validation_data"],
+                'number_of_negative_samples_in_validation_data': dict_init_arg["number_of_negative_samples_in_validation_data"],
+                'threshold': [result['threshold_lst']],
+                'tp': [result['tp_lst']],
+                'fp': [result['fp_lst']],
+                'tn': [result['tn_lst']],
+                'fn': [result['fn_lst']],
+                'accuracy': [result['accuracy_lst']],
+                'ppv': [result['precision_lst']],
+                'recall': [result['recall_lst']],
+                'f1_score': [result['f1_score_lst']],
+                'fnr': [result['fnr_lst']],
+                'fpr': [result['fpr_lst']],
+                'npv': [result['npv_lst']],
+                'fdr': [result['fdr_lst']],
+                'for_': [result['for_lst']],
+                'tnr': [result['tnr_lst']],
+                'auc': result['auc_lst'],
+                "return_code": dict_init_arg['return_code'],
+                "reason": dict_init_arg['reason']
+            }
+        except Exception:
+            result = {
+                'customer_id': dict_init_arg["customer_id_lst"],
+                'training_id': dict_init_arg["training_id_lst"],
+                'model_id': dict_init_arg["model_id_lst"],
+                'profile_id': dict_init_arg["profile_id_lst"],
+                'tag': dict_init_arg["tag_lst"],
+                'model_name': dict_init_arg["model_id_lst"] + "-" + "".join(re.findall(r'\d+', str(datetime.datetime.now()))),
+                'training_start_time': "2000-01-01 00:00:00",
+                'training_end_time': "2000-01-01 00:00:00",
+                'total_training_time': -1,
+                'training_data_start_date': "2000-01-01 00:00:00",
+                'training_data_end_date': "2000-01-01 00:00:00",
+                'number_of_dump_data': -1,
+                'number_of_training_data': -1,
+                'number_of_positive_samples_in_training_data': -1,
+                'number_of_negative_samples_in_training_data': -1,
+                'number_of_validation_data': -1,
+                'true_label_column': dict_init_arg["true_label_column_lst"],
+                'number_of_positive_samples_in_validation_data': -1,
+                'number_of_negative_samples_in_validation_data': -1,
+                'threshold': [[]],
+                'tp': [[]],
+                'fp': [[]],
+                'tn': [[]],
+                'fn': [[]],
+                'accuracy': [[]],
+                'ppv': [[]],
+                'recall': [[]],
+                'f1_score': [[]],
+                'fnr': [[]],
+                'fpr': [[]],
+                'npv': [[]],
+                'fdr': [[]],
+                'for_': [[]],
+                'tnr': [[]],
+                'auc': [[]],
+                "return_code": "dict_init_arg['return_code']",
+                "reason": "dict_init_arg['reason']"
+            }   
         return result
 
     def dict_to_dataframe(self, dict_init_arg: dict):
@@ -112,8 +149,8 @@ class TrainModelToSQl:
         return df
 
     def insert_db(self, data: dict, dict_add_column=None):
-        if not data:
-            return
+        # if not data:
+        #     return
         base_table = create_model_performance(self.table_name)
         if dict_add_column is not None:
             for key in dict_add_column:
@@ -123,7 +160,6 @@ class TrainModelToSQl:
         class User(Base_Model):
             __table__ = base_table
         self.orm.create_table(Base_Model, User)
-        
         data = self.dict_to_dataframe(data)
         self.orm.data_to_DB(data, User)
 
@@ -148,7 +184,7 @@ class GetConfArg:
                 os.kill(0, 4)
             bootstrap_servers.append(host + ":" + port)
 
-        self.mq_info = {
+        self.appollo_info = {
             "servers": bootstrap_servers,
             "customer_id": CUSTOMER_ID,
             "model_id": MODEL_ID,
@@ -239,6 +275,34 @@ class HitrustaiTrainTemple(GetConfArg):
         self.init_logger = init_logger
         self.passwd_so_name = passwd_so_name
         self.model_name = model_name
+        self.dict_init_arg = None
+
+    def error_arg_dict(self):
+        dict_init_arg = {
+            "list_y_test": [],
+            # "list_y_score": np.array(self.df["total_score_fd7"]),
+            "list_y_score": [],
+            "customer_id_lst": self.appollo_info["customer_id"],
+            "training_id_lst": self.appollo_info["training_id"],
+            "model_id_lst": self.appollo_info["model_id"],
+            "profile_id_lst": self.appollo_info["customer_id"],
+            "tag_lst": self.appollo_info["customer_id"],
+            "training_start_time_lst": self.training_start_time_lst,
+            "total_training_time_lst": self.total_training_time_lst,
+
+            "training_end_time_lst": self.training_end_time_lst,
+            "number_of_dump_data": -1,
+            "number_of_training_data": -1,
+            "number_of_positive_samples_in_training_data": -1,
+            "number_of_negative_samples_in_training_data": -1,
+            "number_of_validation_data": -1,
+            "true_label_column_lst": self.dict_model.true_lable_name,
+            "number_of_positive_samples_in_validation_data": -1,
+            "number_of_negative_samples_in_validation_data": -1,
+            "return_code": self.dict_report["return_code"],
+            "reason": self.dict_report["reason"]
+        }
+        return dict_init_arg
 
     def input_arg_dict(self):
         """
@@ -250,7 +314,6 @@ class HitrustaiTrainTemple(GetConfArg):
             "model_id_lst": str,
             "profile_id_lst": str,
             "tag_lst": str,
-            "model_name_lst": str,
             "training_start_time_lst": str,
             "total_training_time_lst": int,
             "training_start_time_lst": datetime,
@@ -272,46 +335,69 @@ class HitrustaiTrainTemple(GetConfArg):
             "list_y_test": list(self.dict_model.df[self.dict_model.true_lable_name]),
             # "list_y_score": np.array(self.df["total_score_fd7"]),
             "list_y_score": np.array,
-            "customer_id_lst": self.mq_info["customer_id"],
-            "training_id_lst": self.mq_info["training_id"],
-            "model_id_lst": self.mq_info["model_id"],
-            "profile_id_lst": self.mq_info["customer_id"],
-            "tag_lst": self.mq_info["customer_id"],
-            "model_name_lst": self.model_name,
+            "customer_id_lst": self.appollo_info["customer_id"],
+            "training_id_lst": self.appollo_info["training_id"],
+            "model_id_lst": self.appollo_info["model_id"],
+            "profile_id_lst": self.appollo_info["customer_id"],
+            "tag_lst": self.appollo_info["customer_id"],
             "training_start_time_lst": self.training_start_time_lst,
             "total_training_time_lst": self.total_training_time_lst,
+
             "training_end_time_lst": self.training_end_time_lst,
-            "number_of_dump_data": self.DATA_TOTAL_ROW,
-            "number_of_training_data": 0,
-            "number_of_positive_samples_in_training_data": list(self.dict_model.df[self.dict_model.true_lable_name]).count(0),
-            "number_of_negative_samples_in_training_data": list(self.dict_model.df[self.dict_model.true_lable_name]).count(1),
-            "number_of_validation_data": 0,
+            "number_of_dump_data": self.dict_model.DATA_TOTAL_ROW,
+            "number_of_training_data": self.dict_model.DATA_TOTAL_ROW_TRAIN,
+            "number_of_positive_samples_in_training_data": self.dict_model.VAL_POSITION_NUMBER,
+            "number_of_negative_samples_in_training_data": self.dict_model.VAL_POSITION_NEGATIVE,
+            "number_of_validation_data": self.dict_model.DATA_TOTAL_ROW_VAL,
             "true_label_column_lst": self.dict_model.true_lable_name,
-            "number_of_positive_samples_in_validation_data": 0,
-            "number_of_negative_samples_in_validation_data": 0,
+            "number_of_positive_samples_in_validation_data": self.dict_model.VAL_POSITION_NUMBER_VAL,
+            "number_of_negative_samples_in_validation_data": self.dict_model.VAL_POSITION_NEGATIVE_VAL,
             "return_code": self.dict_report["return_code"],
-            "reason": str
+            "reason": self.dict_report["reason"]
         }
         return dict_init_arg
 
     def train(self):
-        config = AutoConfig(search_path=os.getcwd() + "/env")
-        if config('ENV_METHOD') == "env":
-            self.read_train_conf_env()
-        else:
-            self.read_train_conf_apollo()
-        t1 = time.time()
-        self.training_start_time_lst = datetime.datetime.now()
-        self.dict_report = self.dict_model.train()
-        self.total_training_time_lst = time.time() - t1
-        self.training_end_time_lst = datetime.datetime.now()
-        self.DATA_START_DATE = self.dict_model.DATA_START_DATE
-        self.DATA_END_DARE = self.dict_model.DATA_END_DARE
-        self.DATA_TOTAL_ROW = self.dict_model.DATA_TOTAL_ROW
+        try:
+            config = AutoConfig(search_path=os.getcwd() + "/env")
+            if config('ENV_METHOD') == "env":
+                self.read_train_conf_env()
+            else:
+                self.read_train_conf_apollo()
+            t1 = time.time()
+            self.training_start_time_lst = datetime.datetime.now()
+            self.dict_report = self.dict_model.train()
+            self.total_training_time_lst = time.time() - t1
+            self.training_end_time_lst = datetime.datetime.now()
+            self.DATA_START_DATE = self.dict_model.DATA_START_DATE
+            self.DATA_END_DARE = self.dict_model.DATA_END_DARE
+            self.DATA_TOTAL_ROW = self.dict_model.DATA_TOTAL_ROW
 
-        self.dict_init_arg = self.input_arg_dict()
+            self.dict_init_arg = self.input_arg_dict()
 
+        except Exception as e:
+            self.training_start_time_lst = "2000-01-01 00:00:00"
+            self.total_training_time_lst = -1
+            self.training_end_time_lst = "2000-01-01 00:00:00"
+            self.DATA_START_DATE = "2000-01-01 00:00:00"
+            self.DATA_END_DARE = "2000-01-01 00:00:00"
+            self.DATA_TOTAL_ROW = -1
+            
+            self.dict_init_arg = self.error_arg_dict()
+            self.dict_init_arg["reason"] = e.args[0]
+            if self.dict_report["return_code"] == "4001":
+                self.dict_init_arg["return_code"] = "9914"
 
+    def insert_db(self, table_name, dict_add_column=None):
+        tmts = TrainModelToSQl(
+            host=self.appollo_info["DB_HOST"],
+            port=self.appollo_info["DB_PORT"],
+            user=self.appollo_info["DB_USERNAME"],
+            passwd=self.appollo_info["DB_PASS"],
+            db=self.appollo_info["DB_NAME"],
+            table_name=table_name
+        )
+        tmts.insert_db(data=self.dict_init_arg, dict_add_column=dict_add_column)
 
 if __name__ == '__main__':
     from hitrustai_lab.model_train.ai_module_train import TrainModelToSQl
@@ -319,8 +405,6 @@ if __name__ == '__main__':
         "add_column1": Column("add_column1", Integer, primary_key=True),
         "add_column2": Column("add_column2", Integer, primary_key=True)
     }
-    dict_init_arg["add_column1"] = 0
-    dict_init_arg["add_column2"] = 0
 
     tmts = TrainModelToSQl(
         host="192.168.10.203",
